@@ -4,6 +4,7 @@ from httoop.util import Unicode
 
 
 class Codec(object):
+
 	@classmethod
 	def decode(cls, data, charset=None, mimetype=None):  # pragma: no cover
 		if isinstance(data, bytes):
@@ -18,8 +19,10 @@ class Codec(object):
 
 	@classmethod
 	def iterencode(cls, data, charset=None, mimetype=None):  # pragma: no cover
-		return cls.encode(data, charset, mimetype)
+		for part in data:
+			yield cls.encode(part, charset, mimetype)
 
 	@classmethod
 	def iterdecode(cls, data, charset=None, mimetype=None):  # pragma: no cover
-		return cls.decode(data, charset, mimetype)
+		for part in data:
+			yield cls.decode(part, charset, mimetype)
