@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-from httoop.authentication import AuthRequestElement, AuthResponseElement, AuthInfoElement
+from httoop.authentication import AuthInfoElement, AuthRequestElement, AuthResponseElement
 from httoop.header.element import _HopByHopElement, _ListElement
 
 
