@@ -3,13 +3,16 @@
 """
 
 from __future__ import absolute_import
-from httoop.util import Unicode, PY3
+
+from httoop.util import PY3, Unicode
 
 __all__ = ['HTTPSemantic']
 
 
 class Semantic(object):
 
+	__slots__ = ()
+
 	def __str__(self):
 		return self.__unicode__() if PY3 else self.__bytes__()
 
@@ -23,7 +26,7 @@ class Semantic(object):
 		raise NotImplementedError('%s.parse(%.5r)' % (type(self).__name__, data))
 
 	def compose(self):  # pragma: no cover
-		raise NotImplementedError('%s.compose()' % (type(self).__name__,))
+		raise NotImplementedError('%s.compose()' % (type(self).__name__, ))
 
 	def __eq__(self, other):
 		if isinstance(other, Unicode):
@@ -39,6 +42,9 @@ class Semantic(object):
 	def __le__(self, other):
 		return self == other or self < other
 
+	def __format__(self, format_spec):
+		return format(str(self), format_spec)
+
 	def __repr__(self):
 		return '<HTTP %s(0x%x)>' % (self.__class__.__name__, id(self))
 
