@@ -1,4 +1,5 @@
 from __future__ import absolute_import
 
-from six import with_metaclass, reraise, string_types, iterbytes, int2byte, PY2, PY3
+from six import PY2, PY3, int2byte, iterbytes, reraise, string_types, with_metaclass
+
 __all__ = ('with_metaclass', 'reraise', 'string_types', 'iterbytes', 'int2byte', 'PY2', 'PY3')
